@@ -1,7 +1,7 @@
 package List::Lazy;
-our $AUTHORITY = 'cpan:YANICK'; 
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Generate lists lazily
-$List::Lazy::VERSION = '0.3.2';
+$List::Lazy::VERSION = '0.3.3';
 
 
 
@@ -45,7 +45,7 @@ sub lazy_list :prototype(&@) { goto &_lazy_list }
 sub _lazy_range ($min,$max,$step=1) {
     my $it = ref $step ? $step : sub { $_ + $step };
 
-    return scalar lazy_list { 
+    return scalar lazy_list {
         return if defined $max and  $_ > $max;
         my $current = $_;
         $_ = $it->();
@@ -67,7 +67,7 @@ sub lazy_fixed_list {
 
 has generator => (
     is => 'ro',
-    required => 1, 
+    required => 1,
 );
 
 has state => (
@@ -78,7 +78,7 @@ has _next => (
     is => 'rw',
     handles_via => 'Array',
     handles => {
-        has_next   => 'count', 
+        has_next   => 'count',
         shift_next => 'shift',
         push_next => 'push',
         _all_next => 'elements',
@@ -131,15 +131,19 @@ sub all ($self) {
     return $self->next(1E99);
 }
 
-sub reduce($self,$reducer,$reduced=undef) {
-    $reduced = $self->next if @_ < 3;
+{
+    no warnings;
 
-    while( my $next = $self->next ) {
-        local ( $::a, $::b ) = ( $reduced, $next );
-        $reduced = $reducer->();
+    sub reduce($self,$reducer,$reduced=undef) {
+        $reduced = $self->next if @_ < 3;
+
+        while( my $next = $self->next ) {
+            local ( $::a, $::b ) = ( $reduced, $next );
+            $reduced = $reducer->();
+        }
+
+        return $reduced;
     }
-
-    return $reduced;
 }
 
 sub map($self,$map) {
@@ -179,7 +183,7 @@ sub grep($self,$filter) {
 
 sub spy($self,$sub=undef) {
     $sub ||= sub { carp $_ };
-    $self->map(sub{ $sub->(); $_ } ); 
+    $self->map(sub{ $sub->(); $_ } );
 }
 
 sub _clone($self,%args) {
@@ -242,7 +246,7 @@ List::Lazy - Generate lists lazily
 
 =head1 VERSION
 
-version 0.3.2
+version 0.3.3
 
 =head1 SYNOPSIS
 
@@ -258,7 +262,7 @@ C<List::Lazy> creates lists that lazily evaluate their next values on-demand.
 
 =head1 EXPORTED FUNCTIONS
 
-Lazy::List doesn't export any function by default, but will export the three following 
+Lazy::List doesn't export any function by default, but will export the three following
 functions on request.
 
 =head2 lazy_list
@@ -282,9 +286,9 @@ which will be seamlessly expanded.
 
     my $range = lazy_range $min, $max, $iterator;
 
-Creates a list iterating over a range of values. C<$min> and C<$max> are required, but C<$max>  can be 
-C<undef> (meaning no upper limit). The C<$iterator> is optional and defaults to the value C<1>. 
-The C<$iterator> can be a number, which will be the step at which the numbers are increased, or a coderef that will 
+Creates a list iterating over a range of values. C<$min> and C<$max> are required, but C<$max>  can be
+C<undef> (meaning no upper limit). The C<$iterator> is optional and defaults to the value C<1>.
+The C<$iterator> can be a number, which will be the step at which the numbers are increased, or a coderef that will
 be passed the previous value as C<$_>, and is expected to return the next value.
 
     my $palinumbers = lazy_range 99, undef, sub { do { $_++ } until $_ eq reverse $_; $_ };
@@ -295,7 +299,7 @@ be passed the previous value as C<$_>, and is expected to return the next value.
 
     my $list = lazy_fixed_list @some_array;
 
-Creates a lazy list that will returns the values of the given array. 
+Creates a lazy list that will returns the values of the given array.
 
 =head1 CLASS
 
@@ -346,7 +350,7 @@ that many items left). C<$num> defaults to C<1>.
     my $value = $list->reduce( $reducing_sub, $initial_value );
 
 Iterates through the list and reduces its values via the C<$reducing_sub>, which
-will be passed the cumulative value and the next item via C<$a> and C<$b>. 
+will be passed the cumulative value and the next item via C<$a> and C<$b>.
 If C<$initial_value> is not given, it defaults to the first element of the list.
 
     my $sum = lazy_range( 1, 100 )->reduce( sub { $a + $b } );
@@ -359,7 +363,7 @@ Creates a new list where the items of the original list are batched in groups
 of C<$n> (or less for the last batch).
 
     my $list = lazy_fixed_list( 1..100 )->batch(3);
-    
+
     my $x = $list->next;           # $x == [ 1, 2, 3]
 
 =head2 map
@@ -368,7 +372,7 @@ of C<$n> (or less for the last batch).
 
 Creates a new list by applying the transformation given by C<$mapper_sub> to the
 original list. The sub ill be passed the original next item via C<$_>
-and is expected to return its transformation, which 
+and is expected to return its transformation, which
 can modify the item, explode it into many items, or suppress it,
 
 Note that the new list do a deep clone of the original list's state, so reading
@@ -395,7 +399,7 @@ from the new list won't affect the original list.
     my $new_list = $list->spy( $sub );
 
 Creates a new list that will execute the spy C<$sub> for
-every value it sees (with the value assigned to C<$_>). 
+every value it sees (with the value assigned to C<$_>).
 
 If C<$sub> is not given, it'll C<carp> the values.
 
@@ -413,7 +417,7 @@ as the condition is met.
     my $new_list = $list->append( @other_lists );
 
 Creates a new list that will return first the elements of C<$list>,
-and those of the C<@other_lists>. 
+and those of the C<@other_lists>.
 
 Note that the new list do a deep clone of the original lists's state, so reading
 from the new list won't affect the original lists.
@@ -434,7 +438,7 @@ from the new list won't affect the original lists.
 
     my @rest = $list->all;
 
-Returns all the remaining values of the list. Be careful: if the list is unbounded, 
+Returns all the remaining values of the list. Be careful: if the list is unbounded,
 calling C<all()> on it will result into an infinite loop.
 
 =head1 AUTHOR
@@ -443,7 +447,7 @@ Yanick Champoux <yanick@babyl.dyndns.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2016 by Yanick Champoux.
+This software is copyright (c) 2022 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
